@@ -10,8 +10,8 @@ import (
 	"os/exec"
 	"path/filepath"
 
-	"github.com/containers/storage/pkg/fileutils"
 	"github.com/spf13/cobra"
+	"go.podman.io/storage/pkg/fileutils"
 )
 
 var uninstallCmd = &cobra.Command{
@@ -27,7 +27,7 @@ func init() {
 	rootCmd.AddCommand(uninstallCmd)
 }
 
-func uninstall(cmd *cobra.Command, args []string) error {
+func uninstall(_ *cobra.Command, _ []string) error {
 	userName, _, homeDir, err := getUser()
 	if err != nil {
 		return err
