@@ -7,8 +7,6 @@ import (
 	"fmt"
 	"os"
 
-	"github.com/containers/common/pkg/completion"
-	"github.com/containers/common/pkg/strongunits"
 	"github.com/containers/podman/v5/cmd/podman/registry"
 	ldefine "github.com/containers/podman/v5/libpod/define"
 	"github.com/containers/podman/v5/libpod/events"
@@ -18,6 +16,9 @@ import (
 	"github.com/shirou/gopsutil/v4/mem"
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
+	"go.podman.io/common/pkg/completion"
+	"go.podman.io/common/pkg/strongunits"
+	"go.podman.io/image/v5/types"
 )
 
 var (
@@ -41,6 +42,7 @@ var (
 // Flags which have a meaning when unspecified that differs from the flag default
 type InitOptionalFlags struct {
 	UserModeNetworking bool
+	tlsVerify          bool
 }
 
 // maxMachineNameSize is set to thirty to limit huge machine names primarily
@@ -154,6 +156,9 @@ func init() {
 	userModeNetFlagName := "user-mode-networking"
 	flags.BoolVar(&initOptionalFlags.UserModeNetworking, userModeNetFlagName, false,
 		"Whether this machine should use user-mode networking, routing traffic through a host user-space process")
+
+	flags.BoolVar(&initOptionalFlags.tlsVerify, "tls-verify", true,
+		"Require HTTPS and verify certificates when contacting registries")
 }
 
 func initMachine(cmd *cobra.Command, args []string) error {
@@ -219,6 +224,16 @@ func initMachine(cmd *cobra.Command, args []string) error {
 		}
 	}
 
+	// initOpts.SkipTlsVerify defaults to OptionalBoolUndefined, which means the backend library
+	// decides whether to verify TLS. We only explicitly set it if the user specifies the
+	// --tls-verify flag on the CLI.
+	//
+	// The flag value from initOptionalFlags.tlsVerify indicates whether TLS verification is desired.
+	// Since we are converting tlsVerify -> SkipTlsVerify, we must invert the bool accordingly.
+	if cmd.Flags().Changed("tls-verify") {
+		initOpts.SkipTlsVerify = types.NewOptionalBool(!initOptionalFlags.tlsVerify)
+	}
+
 	// TODO need to work this back in
 	// if finished, err := vm.Init(initOpts); err != nil || !finished {
 	// 	// Finished = true,  err  = nil  -  Success! Log a message with further instructions
