@@ -1,20 +1,22 @@
 package file
 
 import (
+	"errors"
 	"fmt"
+	"io/fs"
 	"os"
 	"path/filepath"
 	"strconv"
 	"syscall"
 
-	"github.com/containers/storage/pkg/fileutils"
-	"github.com/containers/storage/pkg/lockfile"
 	"github.com/sirupsen/logrus"
+	"go.podman.io/storage/pkg/fileutils"
+	"go.podman.io/storage/pkg/lockfile"
 )
 
 // FileLocks is a struct enabling POSIX lock locking in a shared memory
 // segment.
-type FileLocks struct { //nolint:revive // struct name stutters
+type FileLocks struct {
 	lockPath string
 	valid    bool
 }
@@ -25,7 +27,7 @@ func CreateFileLock(path string) (*FileLocks, error) {
 	if err == nil {
 		return nil, fmt.Errorf("directory %s exists: %w", path, syscall.EEXIST)
 	}
-	if err := os.MkdirAll(path, 0711); err != nil {
+	if err := os.MkdirAll(path, 0o711); err != nil {
 		return nil, err
 	}
 
@@ -79,7 +81,7 @@ func (locks *FileLocks) AllocateLock() (uint32, error) {
 	id := uint32(0)
 	for ; ; id++ {
 		path := locks.getLockPath(id)
-		f, err := os.OpenFile(path, os.O_RDWR|os.O_CREATE|os.O_EXCL, 0666)
+		f, err := os.OpenFile(path, os.O_RDWR|os.O_CREATE|os.O_EXCL, 0o666)
 		if err != nil {
 			if os.IsExist(err) {
 				continue
@@ -101,7 +103,7 @@ func (locks *FileLocks) AllocateGivenLock(lck uint32) error {
 		return fmt.Errorf("locks have already been closed: %w", syscall.EINVAL)
 	}
 
-	f, err := os.OpenFile(locks.getLockPath(lck), os.O_RDWR|os.O_CREATE|os.O_EXCL, 0666)
+	f, err := os.OpenFile(locks.getLockPath(lck), os.O_RDWR|os.O_CREATE|os.O_EXCL, 0o666)
 	if err != nil {
 		return fmt.Errorf("creating lock %d: %w", lck, err)
 	}
@@ -138,7 +140,9 @@ func (locks *FileLocks) DeallocateAllLocks() error {
 		p := filepath.Join(locks.lockPath, f.Name())
 		err := os.Remove(p)
 		if err != nil {
-			lastErr = err
+			if errors.Is(err, fs.ErrNotExist) {
+				continue
+			}
 			logrus.Errorf("Deallocating lock %s", p)
 		}
 	}
