@@ -1,6 +1,8 @@
+//go:build !remote
+
 package libpod
 
-import "github.com/containers/common/libnetwork/types"
+import "go.podman.io/common/libnetwork/types"
 
 // State is a storage backend for libpod's current state.
 // A State is only initialized once per instance of libpod.
