@@ -1,3 +1,5 @@
+//go:build !remote
+
 package compat
 
 import (
@@ -8,9 +10,6 @@ import (
 	"strings"
 	"time"
 
-	"github.com/containers/common/pkg/config"
-	"github.com/containers/common/pkg/sysinfo"
-	"github.com/containers/image/v5/pkg/sysregistriesv2"
 	"github.com/containers/podman/v5/libpod"
 	"github.com/containers/podman/v5/libpod/define"
 	"github.com/containers/podman/v5/pkg/api/handlers"
@@ -23,6 +22,9 @@ import (
 	"github.com/google/uuid"
 	"github.com/opencontainers/selinux/go-selinux"
 	log "github.com/sirupsen/logrus"
+	"go.podman.io/common/pkg/config"
+	"go.podman.io/common/pkg/sysinfo"
+	"go.podman.io/image/v5/pkg/sysregistriesv2"
 )
 
 func GetInfo(w http.ResponseWriter, r *http.Request) {
@@ -53,53 +55,52 @@ func GetInfo(w http.ResponseWriter, r *http.Request) {
 	// liveRestoreEnabled := criu.CheckForCriu() && configInfo.RuntimeSupportsCheckpoint()
 	info := &handlers.Info{
 		Info: dockerSystem.Info{
-			Architecture:       goRuntime.GOARCH,
-			BridgeNfIP6tables:  !sysInfo.BridgeNFCallIP6TablesDisabled,
-			BridgeNfIptables:   !sysInfo.BridgeNFCallIPTablesDisabled,
-			CPUCfsPeriod:       sysInfo.CPUCfsPeriod,
-			CPUCfsQuota:        sysInfo.CPUCfsQuota,
-			CPUSet:             sysInfo.Cpuset,
-			CPUShares:          sysInfo.CPUShares,
-			CgroupDriver:       configInfo.Engine.CgroupManager,
-			ContainerdCommit:   dockerSystem.Commit{},
-			Containers:         infoData.Store.ContainerStore.Number,
-			ContainersPaused:   stateInfo[define.ContainerStatePaused],
-			ContainersRunning:  stateInfo[define.ContainerStateRunning],
-			ContainersStopped:  stateInfo[define.ContainerStateStopped] + stateInfo[define.ContainerStateExited],
-			Debug:              log.IsLevelEnabled(log.DebugLevel),
-			DefaultRuntime:     configInfo.Engine.OCIRuntime,
-			DockerRootDir:      infoData.Store.GraphRoot,
-			Driver:             infoData.Store.GraphDriverName,
-			DriverStatus:       getGraphStatus(infoData.Store.GraphStatus),
-			ExperimentalBuild:  true,
-			GenericResources:   nil,
-			HTTPProxy:          getEnv("http_proxy"),
-			HTTPSProxy:         getEnv("https_proxy"),
-			ID:                 uuid.New().String(),
-			IPv4Forwarding:     !sysInfo.IPv4ForwardingDisabled,
-			Images:             infoData.Store.ImageStore.Number,
-			IndexServerAddress: "",
-			InitBinary:         "",
-			InitCommit:         dockerSystem.Commit{},
-			Isolation:          "",
-			KernelMemoryTCP:    false,
-			KernelVersion:      infoData.Host.Kernel,
-			Labels:             nil,
-			LiveRestoreEnabled: false,
-			LoggingDriver:      "",
-			MemTotal:           infoData.Host.MemTotal,
-			MemoryLimit:        sysInfo.MemoryLimit,
-			NCPU:               goRuntime.NumCPU(),
-			NEventsListener:    0,
-			NFd:                getFdCount(),
-			NGoroutines:        goRuntime.NumGoroutine(),
-			Name:               infoData.Host.Hostname,
-			NoProxy:            getEnv("no_proxy"),
-			OSType:             goRuntime.GOOS,
-			OSVersion:          infoData.Host.Distribution.Version,
-			OomKillDisable:     sysInfo.OomKillDisable,
-			OperatingSystem:    infoData.Host.Distribution.Distribution,
-			PidsLimit:          sysInfo.PidsLimit,
+			Architecture:        goRuntime.GOARCH,
+			CPUCfsPeriod:        sysInfo.CPUCfsPeriod,
+			CPUCfsQuota:         sysInfo.CPUCfsQuota,
+			CPUSet:              sysInfo.Cpuset,
+			CPUShares:           sysInfo.CPUShares,
+			CgroupDriver:        configInfo.Engine.CgroupManager,
+			ContainerdCommit:    dockerSystem.Commit{},
+			Containers:          infoData.Store.ContainerStore.Number,
+			ContainersPaused:    stateInfo[define.ContainerStatePaused],
+			ContainersRunning:   stateInfo[define.ContainerStateRunning],
+			ContainersStopped:   stateInfo[define.ContainerStateStopped] + stateInfo[define.ContainerStateExited],
+			Debug:               log.IsLevelEnabled(log.DebugLevel),
+			DefaultAddressPools: getDefaultAddressPools(configInfo),
+			DefaultRuntime:      configInfo.Engine.OCIRuntime,
+			DockerRootDir:       infoData.Store.GraphRoot,
+			Driver:              infoData.Store.GraphDriverName,
+			DriverStatus:        getGraphStatus(infoData.Store.GraphStatus),
+			ExperimentalBuild:   true,
+			GenericResources:    nil,
+			HTTPProxy:           getEnv("http_proxy"),
+			HTTPSProxy:          getEnv("https_proxy"),
+			ID:                  uuid.New().String(),
+			IPv4Forwarding:      !sysInfo.IPv4ForwardingDisabled,
+			Images:              infoData.Store.ImageStore.Number,
+			IndexServerAddress:  "",
+			InitBinary:          "",
+			InitCommit:          dockerSystem.Commit{},
+			Isolation:           "",
+			KernelMemoryTCP:     false,
+			KernelVersion:       infoData.Host.Kernel,
+			Labels:              nil,
+			LiveRestoreEnabled:  false,
+			LoggingDriver:       "",
+			MemTotal:            infoData.Host.MemTotal,
+			MemoryLimit:         sysInfo.MemoryLimit,
+			NCPU:                goRuntime.NumCPU(),
+			NEventsListener:     0,
+			NFd:                 getFdCount(),
+			NGoroutines:         goRuntime.NumGoroutine(),
+			Name:                infoData.Host.Hostname,
+			NoProxy:             getEnv("no_proxy"),
+			OSType:              goRuntime.GOOS,
+			OSVersion:           infoData.Host.Distribution.Version,
+			OomKillDisable:      sysInfo.OomKillDisable,
+			OperatingSystem:     infoData.Host.Distribution.Distribution,
+			PidsLimit:           sysInfo.PidsLimit,
 			Plugins: dockerSystem.PluginsInfo{
 				Volume:  infoData.Plugins.Volume,
 				Network: infoData.Plugins.Network,
@@ -235,3 +236,24 @@ func getEnv(value string) string {
 	}
 	return ""
 }
+
+func getDefaultAddressPools(configInfo *config.Config) []dockerSystem.NetworkAddressPool {
+	// Convert DefaultSubnetPools to DefaultAddressPools
+	if len(configInfo.Network.DefaultSubnetPools) == 0 {
+		return nil
+	}
+
+	pools := make([]dockerSystem.NetworkAddressPool, 0, len(configInfo.Network.DefaultSubnetPools))
+	for _, pool := range configInfo.Network.DefaultSubnetPools {
+		if pool.Base == nil {
+			continue
+		}
+
+		pools = append(pools, dockerSystem.NetworkAddressPool{
+			Base: pool.Base.String(),
+			Size: pool.Size,
+		})
+	}
+
+	return pools
+}
