@@ -8,6 +8,7 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"maps"
 	"os"
 	"path/filepath"
 	"strconv"
@@ -16,12 +17,6 @@ import (
 
 	buildahDefine "github.com/containers/buildah/define"
 	bparse "github.com/containers/buildah/pkg/parse"
-	"github.com/containers/common/libimage"
-	nettypes "github.com/containers/common/libnetwork/types"
-	"github.com/containers/common/pkg/config"
-	"github.com/containers/common/pkg/secrets"
-	"github.com/containers/image/v5/docker/reference"
-	"github.com/containers/image/v5/types"
 	"github.com/containers/podman/v5/cmd/podman/parse"
 	"github.com/containers/podman/v5/libpod"
 	"github.com/containers/podman/v5/libpod/define"
@@ -38,12 +33,18 @@ import (
 	"github.com/containers/podman/v5/pkg/specgenutil"
 	"github.com/containers/podman/v5/pkg/systemd/notifyproxy"
 	"github.com/containers/podman/v5/pkg/util"
-	"github.com/containers/podman/v5/utils"
-	"github.com/containers/storage/pkg/fileutils"
 	"github.com/coreos/go-systemd/v22/daemon"
 	"github.com/opencontainers/go-digest"
 	"github.com/opencontainers/selinux/go-selinux"
 	"github.com/sirupsen/logrus"
+	"go.podman.io/common/libimage"
+	nettypes "go.podman.io/common/libnetwork/types"
+	"go.podman.io/common/pkg/config"
+	"go.podman.io/common/pkg/secrets"
+	"go.podman.io/image/v5/docker/reference"
+	"go.podman.io/image/v5/types"
+	"go.podman.io/storage/pkg/archive"
+	"go.podman.io/storage/pkg/fileutils"
 	yamlv3 "gopkg.in/yaml.v3"
 	"sigs.k8s.io/yaml"
 )
@@ -135,7 +136,7 @@ func (ic *ContainerEngine) prepareAutomountImages(ctx context.Context, forContai
 		return nil, nil
 	}
 
-	for _, imageName := range strings.Split(automount, ";") {
+	for imageName := range strings.SplitSeq(automount, ";") {
 		img, fullName, err := ic.Libpod.LibimageRuntime().LookupImage(imageName, nil)
 		if err != nil {
 			return nil, fmt.Errorf("image %s from container %s does not exist in local storage, cannot automount: %w", imageName, forContainer, err)
@@ -810,8 +811,7 @@ func (ic *ContainerEngine) playKubePod(ctx context.Context, podName string, podY
 			defaultMode := v.DefaultMode
 			// Create files and add data to the volume mountpoint based on the Items in the volume
 			for k, v := range v.Items {
-				dataPath := filepath.Join(mountPoint, k)
-				f, err := os.Create(dataPath)
+				f, err := openPathSafely(mountPoint, k)
 				if err != nil {
 					return nil, nil, fmt.Errorf("cannot create file %q at volume mountpoint %q: %w", k, mountPoint, err)
 				}
@@ -821,7 +821,7 @@ func (ic *ContainerEngine) playKubePod(ctx context.Context, podName string, podY
 					return nil, nil, err
 				}
 				// Set file permissions
-				if err := os.Chmod(f.Name(), os.FileMode(defaultMode)); err != nil {
+				if err := f.Chmod(os.FileMode(defaultMode)); err != nil {
 					return nil, nil, err
 				}
 			}
@@ -957,9 +957,8 @@ func (ic *ContainerEngine) playKubePod(ctx context.Context, podName string, podY
 			return nil, nil, err
 		}
 
-		for k, v := range podSpec.PodSpecGen.Labels { // add podYAML labels
-			labels[k] = v
-		}
+		// add podYAML labels
+		maps.Copy(labels, podSpec.PodSpecGen.Labels)
 		initCtrType := annotations[define.InitContainerType]
 		if initCtrType == "" {
 			initCtrType = define.OneShotInitContainer
@@ -1051,9 +1050,8 @@ func (ic *ContainerEngine) playKubePod(ctx context.Context, podName string, podY
 			return nil, nil, err
 		}
 
-		for k, v := range podSpec.PodSpecGen.Labels { // add podYAML labels
-			labels[k] = v
-		}
+		// add podYAML labels
+		maps.Copy(labels, podSpec.PodSpecGen.Labels)
 
 		automountImages, err := ic.prepareAutomountImages(ctx, container.Name, annotations)
 		if err != nil {
@@ -1091,6 +1089,7 @@ func (ic *ContainerEngine) playKubePod(ctx context.Context, podName string, podY
 			VolumesFrom:        volumesFrom,
 			ImageVolumes:       automountImages,
 			UtsNSIsHost:        p.UtsNs.IsHost(),
+			NoPodPrefix:        options.NoPodPrefix,
 		}
 
 		if podYAML.Spec.TerminationGracePeriodSeconds != nil {
@@ -1504,7 +1503,7 @@ func (ic *ContainerEngine) importVolume(ctx context.Context, vol *libpod.Volume,
 	}
 
 	// dont care if volume is mounted or not we are gonna import everything to mountPoint
-	return utils.UntarToFileSystem(mountPoint, tarFile, nil)
+	return archive.Untar(tarFile, mountPoint, nil)
 }
 
 // readConfigMapFromFile returns a kubernetes configMap obtained from --configmap flag
@@ -1549,7 +1548,7 @@ func splitMultiDocYAML(yamlContent []byte) ([][]byte, error) {
 
 	d := yamlv3.NewDecoder(bytes.NewReader(yamlContent))
 	for {
-		var o interface{}
+		var o any
 		// read individual document
 		err := d.Decode(&o)
 		if err == io.EOF {
