@@ -1,8 +1,13 @@
 package define
 
-import "net/url"
+import (
+	"net/url"
+
+	"go.podman.io/image/v5/types"
+)
 
 type InitOptions struct {
+	PlaybookPath       string
 	CPUS               uint64
 	DiskSize           uint64
 	IgnitionPath       string
@@ -10,6 +15,7 @@ type InitOptions struct {
 	Volumes            []string
 	IsDefault          bool
 	Memory             uint64
+	Swap               uint64
 	Name               string
 	TimeZone           string
 	URI                url.URL
@@ -19,4 +25,5 @@ type InitOptions struct {
 	UID                string // uid of the user that called machine
 	UserModeNetworking *bool  // nil = use backend/system default, false = disable, true = enable
 	USBs               []string
+	SkipTlsVerify      types.OptionalBool
 }
