@@ -6,13 +6,13 @@ import (
 	"errors"
 	"fmt"
 
-	"github.com/containers/image/v5/image"
-	"github.com/containers/image/v5/manifest"
-	"github.com/containers/image/v5/oci/layout"
-	"github.com/containers/image/v5/types"
 	"github.com/opencontainers/go-digest"
 	specV1 "github.com/opencontainers/image-spec/specs-go/v1"
 	"github.com/sirupsen/logrus"
+	"go.podman.io/image/v5/image"
+	"go.podman.io/image/v5/manifest"
+	"go.podman.io/image/v5/oci/layout"
+	"go.podman.io/image/v5/types"
 )
 
 func GetLocalBlob(ctx context.Context, path string) (*types.BlobInfo, error) {
@@ -35,9 +35,6 @@ func GetLocalBlob(ctx context.Context, path string) (*types.BlobInfo, error) {
 		return nil, err
 	}
 	blobs := img.LayerInfos()
-	if err != nil {
-		return nil, err
-	}
 	if len(blobs) != 1 {
 		return nil, errors.New("invalid disk image")
 	}
