@@ -1,3 +1,5 @@
+//go:build linux || freebsd
+
 package integration
 
 import (
@@ -5,17 +7,16 @@ import (
 	"os"
 	"path/filepath"
 
-	. "github.com/containers/podman/v4/test/utils"
-	. "github.com/onsi/ginkgo"
+	. "github.com/containers/podman/v5/test/utils"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
-	. "github.com/onsi/gomega/gexec"
 )
 
 func buildDataVolumeImage(pTest *PodmanTestIntegration, image, data, dest string) {
 	// Create a dummy file for data volume
 	dummyFile := filepath.Join(pTest.TempDir, data)
-	err := os.WriteFile(dummyFile, []byte(data), 0644)
-	Expect(err).To(BeNil())
+	err := os.WriteFile(dummyFile, []byte(data), 0o644)
+	Expect(err).ToNot(HaveOccurred())
 
 	// Create a data volume container image but no CMD binary in it
 	containerFile := fmt.Sprintf(`FROM scratch
@@ -29,7 +30,7 @@ func createContainersConfFile(pTest *PodmanTestIntegration) {
 	configPath := filepath.Join(pTest.TempDir, "containers.conf")
 	containersConf := []byte("[containers]\nprepare_volume_on_create = true\n")
 	err := os.WriteFile(configPath, containersConf, os.ModePerm)
-	Expect(err).To(BeNil())
+	Expect(err).ToNot(HaveOccurred())
 
 	// Set custom containers.conf file
 	os.Setenv("CONTAINERS_CONF", configPath)
@@ -41,7 +42,7 @@ func createContainersConfFile(pTest *PodmanTestIntegration) {
 func checkDataVolumeContainer(pTest *PodmanTestIntegration, image, cont, dest, data string) {
 	create := pTest.Podman([]string{"create", "--name", cont, image})
 	create.WaitWithDefaultTimeout()
-	Expect(create).Should(Exit(0))
+	Expect(create).Should(ExitCleanly())
 
 	inspect := pTest.InspectContainer(cont)
 	Expect(inspect).To(HaveLen(1))
@@ -52,13 +53,13 @@ func checkDataVolumeContainer(pTest *PodmanTestIntegration, image, cont, dest, d
 
 	volList := pTest.Podman([]string{"volume", "list", "--quiet"})
 	volList.WaitWithDefaultTimeout()
-	Expect(volList).Should(Exit(0))
+	Expect(volList).Should(ExitCleanly())
 	Expect(volList.OutputToStringArray()).To(HaveLen(1))
 	Expect(volList.OutputToStringArray()[0]).To(Equal(mntName))
 
 	// Check the mount source directory
 	files, err := os.ReadDir(mntSource)
-	Expect(err).To(BeNil())
+	Expect(err).ToNot(HaveOccurred())
 
 	if data == "" {
 		Expect(files).To(BeEmpty())
@@ -69,27 +70,6 @@ func checkDataVolumeContainer(pTest *PodmanTestIntegration, image, cont, dest, d
 }
 
 var _ = Describe("Podman create data volume", func() {
-	var (
-		tempdir    string
-		err        error
-		podmanTest *PodmanTestIntegration
-	)
-
-	BeforeEach(func() {
-		tempdir, err = CreateTempDirInTempDir()
-		if err != nil {
-			os.Exit(1)
-		}
-		podmanTest = PodmanTestCreate(tempdir)
-		podmanTest.Setup()
-	})
-
-	AfterEach(func() {
-		podmanTest.Cleanup()
-		f := CurrentGinkgoTestDescription()
-		processTestResult(f)
-		os.Unsetenv("CONTAINERS_CONF")
-	})
 
 	It("podman create with volume data copy turned off", func() {
 		imgName, volData, volDest := "dataimg", "dummy", "/test"
@@ -120,6 +100,6 @@ var _ = Describe("Podman create data volume", func() {
 
 		session := podmanTest.Podman([]string{"run", "--rm", ALPINE, "echo"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 	})
 })
